@@ -3,18 +3,18 @@ import datetime
 from moto.core.responses import BaseResponse
 from moto.core.utils import iso_8601_datetime_with_milliseconds
 from moto.utilities.aws_headers import amz_crc32, amzn_request_id
-from .models import autoscaling_backends
+from .models import autoscaling_backends, AutoScalingBackend
 
 
 class AutoScalingResponse(BaseResponse):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(service_name="autoscaling")
 
     @property
-    def autoscaling_backend(self):
+    def autoscaling_backend(self) -> AutoScalingBackend:
         return autoscaling_backends[self.current_account][self.region]
 
-    def create_launch_configuration(self):
+    def create_launch_configuration(self) -> str:
         instance_monitoring_string = self._get_param("InstanceMonitoring.Enabled")
         if instance_monitoring_string == "true":
             instance_monitoring = True
@@ -22,20 +22,20 @@ class AutoScalingResponse(BaseResponse):
             instance_monitoring = False
         params = self._get_params()
         self.autoscaling_backend.create_launch_configuration(
-            name=params.get("LaunchConfigurationName"),
-            image_id=params.get("ImageId"),
+            name=params.get("LaunchConfigurationName"),  # type: ignore[arg-type]
+            image_id=params.get("ImageId"),  # type: ignore[arg-type]
             key_name=params.get("KeyName"),
-            ramdisk_id=params.get("RamdiskId"),
-            kernel_id=params.get("KernelId"),
+            ramdisk_id=params.get("RamdiskId"),  # type: ignore[arg-type]
+            kernel_id=params.get("KernelId"),  # type: ignore[arg-type]
             security_groups=self._get_multi_param("SecurityGroups.member"),
-            user_data=params.get("UserData"),
-            instance_type=params.get("InstanceType"),
+            user_data=params.get("UserData"),  # type: ignore[arg-type]
+            instance_type=params.get("InstanceType"),  # type: ignore[arg-type]
             instance_monitoring=instance_monitoring,
             instance_profile_name=params.get("IamInstanceProfile"),
             spot_price=params.get("SpotPrice"),
-            ebs_optimized=params.get("EbsOptimized"),
-            associate_public_ip_address=params.get("AssociatePublicIpAddress"),
-            block_device_mappings=params.get("BlockDeviceMappings"),
+            ebs_optimized=params.get("EbsOptimized"),  # type: ignore[arg-type]
+            associate_public_ip_address=params.get("AssociatePublicIpAddress"),  # type: ignore[arg-type]
+            block_device_mappings=params.get("BlockDeviceMappings"),  # type: ignore[arg-type]
             instance_id=params.get("InstanceId"),
             metadata_options=params.get("MetadataOptions"),
             classic_link_vpc_id=params.get("ClassicLinkVPCId"),
@@ -44,7 +44,7 @@ class AutoScalingResponse(BaseResponse):
         template = self.response_template(CREATE_LAUNCH_CONFIGURATION_TEMPLATE)
         return template.render()
 
-    def describe_launch_configurations(self):
+    def describe_launch_configurations(self) -> str:
         names = self._get_multi_param("LaunchConfigurationNames.member")
         all_launch_configurations = (
             self.autoscaling_backend.describe_launch_configurations(names)
@@ -55,9 +55,8 @@ class AutoScalingResponse(BaseResponse):
             start = all_names.index(marker) + 1
         else:
             start = 0
-        max_records = self._get_int_param(
-            "MaxRecords", 50
-        )  # the default is 100, but using 50 to make testing easier
+        # the default is 100, but using 50 to make testing easier
+        max_records = self._get_int_param("MaxRecords") or 50
         launch_configurations_resp = all_launch_configurations[
             start : start + max_records
         ]
@@ -70,13 +69,13 @@ class AutoScalingResponse(BaseResponse):
             launch_configurations=launch_configurations_resp, next_token=next_token
         )
 
-    def delete_launch_configuration(self):
-        launch_configurations_name = self.querystring.get("LaunchConfigurationName")[0]
+    def delete_launch_configuration(self) -> str:
+        launch_configurations_name = self.querystring.get("LaunchConfigurationName")[0]  # type: ignore[index]
         self.autoscaling_backend.delete_launch_configuration(launch_configurations_name)
         template = self.response_template(DELETE_LAUNCH_CONFIGURATION_TEMPLATE)
         return template.render()
 
-    def create_auto_scaling_group(self):
+    def create_auto_scaling_group(self) -> str:
         params = self._get_params()
         self.autoscaling_backend.create_auto_scaling_group(
             name=self._get_param("AutoScalingGroupName"),
@@ -97,7 +96,7 @@ class AutoScalingResponse(BaseResponse):
             placement_group=self._get_param("PlacementGroup"),
             termination_policies=self._get_multi_param("TerminationPolicies.member"),
             tags=self._get_list_prefix("Tags.member"),
-            capacity_rebalance=self._get_bool_param("CapacityRebalance"),
+            capacity_rebalance=self._get_bool_param("CapacityRebalance", False),
             new_instances_protected_from_scale_in=self._get_bool_param(
                 "NewInstancesProtectedFromScaleIn", False
             ),
@@ -105,7 +104,7 @@ class AutoScalingResponse(BaseResponse):
         template = self.response_template(CREATE_AUTOSCALING_GROUP_TEMPLATE)
         return template.render()
 
-    def put_scheduled_update_group_action(self):
+    def put_scheduled_update_group_action(self) -> str:
         self.autoscaling_backend.put_scheduled_update_group_action(
             name=self._get_param("AutoScalingGroupName"),
             desired_capacity=self._get_int_param("DesiredCapacity"),
@@ -119,7 +118,7 @@ class AutoScalingResponse(BaseResponse):
         template = self.response_template(PUT_SCHEDULED_UPDATE_GROUP_ACTION_TEMPLATE)
         return template.render()
 
-    def describe_scheduled_actions(self):
+    def describe_scheduled_actions(self) -> str:
         scheduled_actions = self.autoscaling_backend.describe_scheduled_actions(
             autoscaling_group_name=self._get_param("AutoScalingGroupName"),
             scheduled_action_names=self._get_multi_param("ScheduledActionNames.member"),
@@ -127,7 +126,7 @@ class AutoScalingResponse(BaseResponse):
         template = self.response_template(DESCRIBE_SCHEDULED_ACTIONS)
         return template.render(scheduled_actions=scheduled_actions)
 
-    def delete_scheduled_action(self):
+    def delete_scheduled_action(self) -> str:
         auto_scaling_group_name = self._get_param("AutoScalingGroupName")
         scheduled_action_name = self._get_param("ScheduledActionName")
         self.autoscaling_backend.delete_scheduled_action(
@@ -137,9 +136,13 @@ class AutoScalingResponse(BaseResponse):
         template = self.response_template(DELETE_SCHEDULED_ACTION_TEMPLATE)
         return template.render()
 
+    def describe_scaling_activities(self) -> str:
+        template = self.response_template(DESCRIBE_SCALING_ACTIVITIES_TEMPLATE)
+        return template.render()
+
     @amz_crc32
     @amzn_request_id
-    def attach_instances(self):
+    def attach_instances(self) -> str:
         group_name = self._get_param("AutoScalingGroupName")
         instance_ids = self._get_multi_param("InstanceIds.member")
         self.autoscaling_backend.attach_instances(group_name, instance_ids)
@@ -148,7 +151,7 @@ class AutoScalingResponse(BaseResponse):
 
     @amz_crc32
     @amzn_request_id
-    def set_instance_health(self):
+    def set_instance_health(self) -> str:
         instance_id = self._get_param("InstanceId")
         health_status = self._get_param("HealthStatus")
         if health_status not in ["Healthy", "Unhealthy"]:
@@ -159,7 +162,7 @@ class AutoScalingResponse(BaseResponse):
 
     @amz_crc32
     @amzn_request_id
-    def detach_instances(self):
+    def detach_instances(self) -> str:
         group_name = self._get_param("AutoScalingGroupName")
         instance_ids = self._get_multi_param("InstanceIds.member")
         should_decrement_string = self._get_param("ShouldDecrementDesiredCapacity")
@@ -175,7 +178,7 @@ class AutoScalingResponse(BaseResponse):
 
     @amz_crc32
     @amzn_request_id
-    def attach_load_balancer_target_groups(self):
+    def attach_load_balancer_target_groups(self) -> str:
         group_name = self._get_param("AutoScalingGroupName")
         target_group_arns = self._get_multi_param("TargetGroupARNs.member")
 
@@ -187,7 +190,7 @@ class AutoScalingResponse(BaseResponse):
 
     @amz_crc32
     @amzn_request_id
-    def describe_load_balancer_target_groups(self):
+    def describe_load_balancer_target_groups(self) -> str:
         group_name = self._get_param("AutoScalingGroupName")
         target_group_arns = (
             self.autoscaling_backend.describe_load_balancer_target_groups(group_name)
@@ -197,7 +200,7 @@ class AutoScalingResponse(BaseResponse):
 
     @amz_crc32
     @amzn_request_id
-    def detach_load_balancer_target_groups(self):
+    def detach_load_balancer_target_groups(self) -> str:
         group_name = self._get_param("AutoScalingGroupName")
         target_group_arns = self._get_multi_param("TargetGroupARNs.member")
 
@@ -207,7 +210,7 @@ class AutoScalingResponse(BaseResponse):
         template = self.response_template(DETACH_LOAD_BALANCER_TARGET_GROUPS_TEMPLATE)
         return template.render()
 
-    def describe_auto_scaling_groups(self):
+    def describe_auto_scaling_groups(self) -> str:
         names = self._get_multi_param("AutoScalingGroupNames.member")
         token = self._get_param("NextToken")
         all_groups = self.autoscaling_backend.describe_auto_scaling_groups(names)
@@ -226,7 +229,7 @@ class AutoScalingResponse(BaseResponse):
         template = self.response_template(DESCRIBE_AUTOSCALING_GROUPS_TEMPLATE)
         return template.render(groups=groups, next_token=next_token)
 
-    def update_auto_scaling_group(self):
+    def update_auto_scaling_group(self) -> str:
         self.autoscaling_backend.update_auto_scaling_group(
             name=self._get_param("AutoScalingGroupName"),
             availability_zones=self._get_multi_param("AvailabilityZones.member"),
@@ -245,41 +248,41 @@ class AutoScalingResponse(BaseResponse):
         template = self.response_template(UPDATE_AUTOSCALING_GROUP_TEMPLATE)
         return template.render()
 
-    def delete_auto_scaling_group(self):
+    def delete_auto_scaling_group(self) -> str:
         group_name = self._get_param("AutoScalingGroupName")
         self.autoscaling_backend.delete_auto_scaling_group(group_name)
         template = self.response_template(DELETE_AUTOSCALING_GROUP_TEMPLATE)
         return template.render()
 
-    def set_desired_capacity(self):
+    def set_desired_capacity(self) -> str:
         group_name = self._get_param("AutoScalingGroupName")
         desired_capacity = self._get_int_param("DesiredCapacity")
         self.autoscaling_backend.set_desired_capacity(group_name, desired_capacity)
         template = self.response_template(SET_DESIRED_CAPACITY_TEMPLATE)
         return template.render()
 
-    def create_or_update_tags(self):
+    def create_or_update_tags(self) -> str:
         tags = self._get_list_prefix("Tags.member")
 
         self.autoscaling_backend.create_or_update_tags(tags)
         template = self.response_template(UPDATE_AUTOSCALING_GROUP_TEMPLATE)
         return template.render()
 
-    def delete_tags(self):
+    def delete_tags(self) -> str:
         tags = self._get_list_prefix("Tags.member")
 
         self.autoscaling_backend.delete_tags(tags)
         template = self.response_template(UPDATE_AUTOSCALING_GROUP_TEMPLATE)
         return template.render()
 
-    def describe_auto_scaling_instances(self):
+    def describe_auto_scaling_instances(self) -> str:
         instance_states = self.autoscaling_backend.describe_auto_scaling_instances(
             instance_ids=self._get_multi_param("InstanceIds.member")
         )
         template = self.response_template(DESCRIBE_AUTOSCALING_INSTANCES_TEMPLATE)
         return template.render(instance_states=instance_states)
 
-    def put_lifecycle_hook(self):
+    def put_lifecycle_hook(self) -> str:
         lifecycle_hook = self.autoscaling_backend.create_lifecycle_hook(
             name=self._get_param("LifecycleHookName"),
             as_name=self._get_param("AutoScalingGroupName"),
@@ -290,7 +293,7 @@ class AutoScalingResponse(BaseResponse):
         template = self.response_template(CREATE_LIFECYLE_HOOK_TEMPLATE)
         return template.render(lifecycle_hook=lifecycle_hook)
 
-    def describe_lifecycle_hooks(self):
+    def describe_lifecycle_hooks(self) -> str:
         lifecycle_hooks = self.autoscaling_backend.describe_lifecycle_hooks(
             as_name=self._get_param("AutoScalingGroupName"),
             lifecycle_hook_names=self._get_multi_param("LifecycleHookNames.member"),
@@ -298,27 +301,27 @@ class AutoScalingResponse(BaseResponse):
         template = self.response_template(DESCRIBE_LIFECYCLE_HOOKS_TEMPLATE)
         return template.render(lifecycle_hooks=lifecycle_hooks)
 
-    def delete_lifecycle_hook(self):
+    def delete_lifecycle_hook(self) -> str:
         as_name = self._get_param("AutoScalingGroupName")
         name = self._get_param("LifecycleHookName")
         self.autoscaling_backend.delete_lifecycle_hook(as_name, name)
         template = self.response_template(DELETE_LIFECYCLE_HOOK_TEMPLATE)
         return template.render()
 
-    def put_scaling_policy(self):
+    def put_scaling_policy(self) -> str:
         params = self._get_params()
         policy = self.autoscaling_backend.put_scaling_policy(
-            name=params.get("PolicyName"),
+            name=params.get("PolicyName"),  # type: ignore[arg-type]
             policy_type=params.get("PolicyType", "SimpleScaling"),
-            metric_aggregation_type=params.get("MetricAggregationType"),
-            adjustment_type=params.get("AdjustmentType"),
-            as_name=params.get("AutoScalingGroupName"),
-            min_adjustment_magnitude=params.get("MinAdjustmentMagnitude"),
+            metric_aggregation_type=params.get("MetricAggregationType"),  # type: ignore[arg-type]
+            adjustment_type=params.get("AdjustmentType"),  # type: ignore[arg-type]
+            as_name=params.get("AutoScalingGroupName"),  # type: ignore[arg-type]
+            min_adjustment_magnitude=params.get("MinAdjustmentMagnitude"),  # type: ignore[arg-type]
             scaling_adjustment=self._get_int_param("ScalingAdjustment"),
             cooldown=self._get_int_param("Cooldown"),
             target_tracking_config=params.get("TargetTrackingConfiguration", {}),
             step_adjustments=params.get("StepAdjustments", []),
-            estimated_instance_warmup=params.get("EstimatedInstanceWarmup"),
+            estimated_instance_warmup=params.get("EstimatedInstanceWarmup"),  # type: ignore[arg-type]
             predictive_scaling_configuration=params.get(
                 "PredictiveScalingConfiguration", {}
             ),
@@ -326,7 +329,7 @@ class AutoScalingResponse(BaseResponse):
         template = self.response_template(CREATE_SCALING_POLICY_TEMPLATE)
         return template.render(policy=policy)
 
-    def describe_policies(self):
+    def describe_policies(self) -> str:
         policies = self.autoscaling_backend.describe_policies(
             autoscaling_group_name=self._get_param("AutoScalingGroupName"),
             policy_names=self._get_multi_param("PolicyNames.member"),
@@ -335,13 +338,13 @@ class AutoScalingResponse(BaseResponse):
         template = self.response_template(DESCRIBE_SCALING_POLICIES_TEMPLATE)
         return template.render(policies=policies)
 
-    def delete_policy(self):
+    def delete_policy(self) -> str:
         group_name = self._get_param("PolicyName")
         self.autoscaling_backend.delete_policy(group_name)
         template = self.response_template(DELETE_POLICY_TEMPLATE)
         return template.render()
 
-    def execute_policy(self):
+    def execute_policy(self) -> str:
         group_name = self._get_param("PolicyName")
         self.autoscaling_backend.execute_policy(group_name)
         template = self.response_template(EXECUTE_POLICY_TEMPLATE)
@@ -349,7 +352,7 @@ class AutoScalingResponse(BaseResponse):
 
     @amz_crc32
     @amzn_request_id
-    def attach_load_balancers(self):
+    def attach_load_balancers(self) -> str:
         group_name = self._get_param("AutoScalingGroupName")
         load_balancer_names = self._get_multi_param("LoadBalancerNames.member")
         self.autoscaling_backend.attach_load_balancers(group_name, load_balancer_names)
@@ -358,7 +361,7 @@ class AutoScalingResponse(BaseResponse):
 
     @amz_crc32
     @amzn_request_id
-    def describe_load_balancers(self):
+    def describe_load_balancers(self) -> str:
         group_name = self._get_param("AutoScalingGroupName")
         load_balancers = self.autoscaling_backend.describe_load_balancers(group_name)
         template = self.response_template(DESCRIBE_LOAD_BALANCERS_TEMPLATE)
@@ -366,7 +369,7 @@ class AutoScalingResponse(BaseResponse):
 
     @amz_crc32
     @amzn_request_id
-    def detach_load_balancers(self):
+    def detach_load_balancers(self) -> str:
         group_name = self._get_param("AutoScalingGroupName")
         load_balancer_names = self._get_multi_param("LoadBalancerNames.member")
         self.autoscaling_backend.detach_load_balancers(group_name, load_balancer_names)
@@ -375,7 +378,7 @@ class AutoScalingResponse(BaseResponse):
 
     @amz_crc32
     @amzn_request_id
-    def enter_standby(self):
+    def enter_standby(self) -> str:
         group_name = self._get_param("AutoScalingGroupName")
         instance_ids = self._get_multi_param("InstanceIds.member")
         should_decrement_string = self._get_param("ShouldDecrementDesiredCapacity")
@@ -401,7 +404,7 @@ class AutoScalingResponse(BaseResponse):
 
     @amz_crc32
     @amzn_request_id
-    def exit_standby(self):
+    def exit_standby(self) -> str:
         group_name = self._get_param("AutoScalingGroupName")
         instance_ids = self._get_multi_param("InstanceIds.member")
         (
@@ -417,7 +420,7 @@ class AutoScalingResponse(BaseResponse):
             timestamp=iso_8601_datetime_with_milliseconds(datetime.datetime.utcnow()),
         )
 
-    def suspend_processes(self):
+    def suspend_processes(self) -> str:
         autoscaling_group_name = self._get_param("AutoScalingGroupName")
         scaling_processes = self._get_multi_param("ScalingProcesses.member")
         self.autoscaling_backend.suspend_processes(
@@ -426,7 +429,7 @@ class AutoScalingResponse(BaseResponse):
         template = self.response_template(SUSPEND_PROCESSES_TEMPLATE)
         return template.render()
 
-    def resume_processes(self):
+    def resume_processes(self) -> str:
         autoscaling_group_name = self._get_param("AutoScalingGroupName")
         scaling_processes = self._get_multi_param("ScalingProcesses.member")
         self.autoscaling_backend.resume_processes(
@@ -435,7 +438,7 @@ class AutoScalingResponse(BaseResponse):
         template = self.response_template(RESUME_PROCESSES_TEMPLATE)
         return template.render()
 
-    def set_instance_protection(self):
+    def set_instance_protection(self) -> str:
         group_name = self._get_param("AutoScalingGroupName")
         instance_ids = self._get_multi_param("InstanceIds.member")
         protected_from_scale_in = self._get_bool_param("ProtectedFromScaleIn")
@@ -447,7 +450,7 @@ class AutoScalingResponse(BaseResponse):
 
     @amz_crc32
     @amzn_request_id
-    def terminate_instance_in_auto_scaling_group(self):
+    def terminate_instance_in_auto_scaling_group(self) -> str:
         instance_id = self._get_param("InstanceId")
         should_decrement_string = self._get_param("ShouldDecrementDesiredCapacity")
         if should_decrement_string == "true":
@@ -468,16 +471,16 @@ class AutoScalingResponse(BaseResponse):
             timestamp=iso_8601_datetime_with_milliseconds(datetime.datetime.utcnow()),
         )
 
-    def describe_tags(self):
+    def describe_tags(self) -> str:
         filters = self._get_params().get("Filters", [])
         tags = self.autoscaling_backend.describe_tags(filters=filters)
         template = self.response_template(DESCRIBE_TAGS_TEMPLATE)
         return template.render(tags=tags, next_token=None)
 
-    def enable_metrics_collection(self):
+    def enable_metrics_collection(self) -> str:
         group_name = self._get_param("AutoScalingGroupName")
         metrics = self._get_params().get("Metrics")
-        self.autoscaling_backend.enable_metrics_collection(group_name, metrics)
+        self.autoscaling_backend.enable_metrics_collection(group_name, metrics)  # type: ignore[arg-type]
         template = self.response_template(ENABLE_METRICS_COLLECTION_TEMPLATE)
         return template.render()
 
@@ -883,6 +886,14 @@ DELETE_AUTOSCALING_GROUP_TEMPLATE = """<DeleteAutoScalingGroupResponse xmlns="ht
   </ResponseMetadata>
 </DeleteAutoScalingGroupResponse>"""
 
+DESCRIBE_SCALING_ACTIVITIES_TEMPLATE = """<DescribeScalingActivitiesResponse xmlns="http://autoscaling.amazonaws.com/doc/2011-01-01/">
+<DescribeScalingActivitiesResult>
+</DescribeScalingActivitiesResult>
+<ResponseMetadata>
+<RequestId></RequestId>
+</ResponseMetadata>
+</DescribeScalingActivitiesResponse>"""
+
 DESCRIBE_AUTOSCALING_INSTANCES_TEMPLATE = """<DescribeAutoScalingInstancesResponse xmlns="http://autoscaling.amazonaws.com/doc/2011-01-01/">
   <DescribeAutoScalingInstancesResult>
     <AutoScalingInstances>
