@@ -1,5 +1,6 @@
 """DirectoryServiceBackend class with methods for supported APIs."""
 from datetime import datetime, timezone
+from typing import Any, Dict, Optional, Tuple, List
 
 from moto.core import BaseBackend, BackendDict, BaseModel
 from moto.ds.exceptions import (
@@ -46,17 +47,17 @@ class Directory(BaseModel):  # pylint: disable=too-many-instance-attributes
 
     def __init__(
         self,
-        account_id,
-        region,
-        name,
-        password,
-        directory_type,
-        size=None,
-        vpc_settings=None,
-        connect_settings=None,
-        short_name=None,
-        description=None,
-        edition=None,
+        account_id: str,
+        region: str,
+        name: str,
+        password: str,
+        directory_type: str,
+        size: Optional[str] = None,
+        vpc_settings: Optional[Dict[str, Any]] = None,
+        connect_settings: Optional[Dict[str, Any]] = None,
+        short_name: Optional[str] = None,
+        description: Optional[str] = None,
+        edition: Optional[str] = None,
     ):  # pylint: disable=too-many-arguments
         self.account_id = account_id
         self.region = region
@@ -82,26 +83,26 @@ class Directory(BaseModel):  # pylint: disable=too-many-instance-attributes
 
         if self.directory_type == "ADConnector":
             self.security_group_id = self.create_security_group(
-                self.connect_settings["VpcId"]
+                self.connect_settings["VpcId"]  # type: ignore[index]
             )
             self.eni_ids, self.subnet_ips = self.create_eni(
-                self.security_group_id, self.connect_settings["SubnetIds"]
+                self.security_group_id, self.connect_settings["SubnetIds"]  # type: ignore[index]
             )
-            self.connect_settings["SecurityGroupId"] = self.security_group_id
-            self.connect_settings["ConnectIps"] = self.subnet_ips
-            self.dns_ip_addrs = self.connect_settings["CustomerDnsIps"]
+            self.connect_settings["SecurityGroupId"] = self.security_group_id  # type: ignore[index]
+            self.connect_settings["ConnectIps"] = self.subnet_ips  # type: ignore[index]
+            self.dns_ip_addrs = self.connect_settings["CustomerDnsIps"]  # type: ignore[index]
 
         else:
             self.security_group_id = self.create_security_group(
-                self.vpc_settings["VpcId"]
+                self.vpc_settings["VpcId"]  # type: ignore[index]
             )
             self.eni_ids, self.subnet_ips = self.create_eni(
-                self.security_group_id, self.vpc_settings["SubnetIds"]
+                self.security_group_id, self.vpc_settings["SubnetIds"]  # type: ignore[index]
             )
-            self.vpc_settings["SecurityGroupId"] = self.security_group_id
+            self.vpc_settings["SecurityGroupId"] = self.security_group_id  # type: ignore[index]
             self.dns_ip_addrs = self.subnet_ips
 
-    def create_security_group(self, vpc_id):
+    def create_security_group(self, vpc_id: str) -> str:
         """Create security group for the network interface."""
         security_group_info = ec2_backends[self.account_id][
             self.region
@@ -115,13 +116,15 @@ class Directory(BaseModel):  # pylint: disable=too-many-instance-attributes
         )
         return security_group_info.id
 
-    def delete_security_group(self):
+    def delete_security_group(self) -> None:
         """Delete the given security group."""
         ec2_backends[self.account_id][self.region].delete_security_group(
             group_id=self.security_group_id
         )
 
-    def create_eni(self, security_group_id, subnet_ids):
+    def create_eni(
+        self, security_group_id: str, subnet_ids: List[str]
+    ) -> Tuple[List[str], List[str]]:
         """Return ENI ids and primary addresses created for each subnet."""
         eni_ids = []
         subnet_ips = []
@@ -138,21 +141,21 @@ class Directory(BaseModel):  # pylint: disable=too-many-instance-attributes
             subnet_ips.append(eni_info.private_ip_address)
         return eni_ids, subnet_ips
 
-    def delete_eni(self):
+    def delete_eni(self) -> None:
         """Delete ENI for each subnet and the security group."""
         for eni_id in self.eni_ids:
             ec2_backends[self.account_id][self.region].delete_network_interface(eni_id)
 
-    def update_alias(self, alias):
+    def update_alias(self, alias: str) -> None:
         """Change default alias to given alias."""
         self.alias = alias
         self.access_url = f"{alias}.awsapps.com"
 
-    def enable_sso(self, new_state):
+    def enable_sso(self, new_state: bool) -> None:
         """Enable/disable sso based on whether new_state is True or False."""
         self.sso_enabled = new_state
 
-    def to_dict(self):
+    def to_dict(self) -> Dict[str, Any]:
         """Create a dictionary of attributes for Directory."""
         attributes = {
             "AccessUrl": self.access_url,
@@ -188,19 +191,21 @@ class Directory(BaseModel):  # pylint: disable=too-many-instance-attributes
 class DirectoryServiceBackend(BaseBackend):
     """Implementation of DirectoryService APIs."""
 
-    def __init__(self, region_name, account_id):
+    def __init__(self, region_name: str, account_id: str):
         super().__init__(region_name, account_id)
-        self.directories = {}
+        self.directories: Dict[str, Directory] = {}
         self.tagger = TaggingService()
 
     @staticmethod
-    def default_vpc_endpoint_service(service_region, zones):
+    def default_vpc_endpoint_service(
+        service_region: str, zones: List[str]
+    ) -> List[Dict[str, str]]:
         """List of dicts representing default VPC endpoints for this service."""
         return BaseBackend.default_vpc_endpoint_service_factory(
             service_region, zones, "ds"
         )
 
-    def _verify_subnets(self, region, vpc_settings):
+    def _verify_subnets(self, region: str, vpc_settings: Dict[str, Any]) -> None:
         """Verify subnets are valid, else raise an exception.
 
         If settings are valid, add AvailabilityZones to vpc_settings.
@@ -237,15 +242,15 @@ class DirectoryServiceBackend(BaseBackend):
 
     def connect_directory(
         self,
-        region,
-        name,
-        short_name,
-        password,
-        description,
-        size,
-        connect_settings,
-        tags,
-    ):  # pylint: disable=too-many-arguments
+        region: str,
+        name: str,
+        short_name: str,
+        password: str,
+        description: str,
+        size: str,
+        connect_settings: Dict[str, Any],
+        tags: List[Dict[str, str]],
+    ) -> str:  # pylint: disable=too-many-arguments
         """Create a fake AD Connector."""
         if len(self.directories) > Directory.CONNECTED_DIRECTORIES_LIMIT:
             raise DirectoryLimitExceededException(
@@ -296,8 +301,16 @@ class DirectoryServiceBackend(BaseBackend):
         return directory.directory_id
 
     def create_directory(
-        self, region, name, short_name, password, description, size, vpc_settings, tags
-    ):  # pylint: disable=too-many-arguments
+        self,
+        region: str,
+        name: str,
+        short_name: str,
+        password: str,
+        description: str,
+        size: str,
+        vpc_settings: Dict[str, Any],
+        tags: List[Dict[str, str]],
+    ) -> str:  # pylint: disable=too-many-arguments
         """Create a fake Simple Ad Directory."""
         if len(self.directories) > Directory.CLOUDONLY_DIRECTORIES_LIMIT:
             raise DirectoryLimitExceededException(
@@ -341,7 +354,7 @@ class DirectoryServiceBackend(BaseBackend):
         self.tagger.tag_resource(directory.directory_id, tags or [])
         return directory.directory_id
 
-    def _validate_directory_id(self, directory_id):
+    def _validate_directory_id(self, directory_id: str) -> None:
         """Raise an exception if the directory id is invalid or unknown."""
         # Validation of ID takes precedence over a check for its existence.
         validate_args([("directoryId", directory_id)])
@@ -350,7 +363,7 @@ class DirectoryServiceBackend(BaseBackend):
                 f"Directory {directory_id} does not exist"
             )
 
-    def create_alias(self, directory_id, alias):
+    def create_alias(self, directory_id: str, alias: str) -> Dict[str, str]:
         """Create and assign an alias to a directory."""
         self._validate_directory_id(directory_id)
 
@@ -373,15 +386,15 @@ class DirectoryServiceBackend(BaseBackend):
 
     def create_microsoft_ad(
         self,
-        region,
-        name,
-        short_name,
-        password,
-        description,
-        vpc_settings,
-        edition,
-        tags,
-    ):  # pylint: disable=too-many-arguments
+        region: str,
+        name: str,
+        short_name: str,
+        password: str,
+        description: str,
+        vpc_settings: Dict[str, Any],
+        edition: str,
+        tags: List[Dict[str, str]],
+    ) -> str:  # pylint: disable=too-many-arguments
         """Create a fake Microsoft Ad Directory."""
         if len(self.directories) > Directory.CLOUDONLY_MICROSOFT_AD_LIMIT:
             raise DirectoryLimitExceededException(
@@ -423,7 +436,7 @@ class DirectoryServiceBackend(BaseBackend):
         self.tagger.tag_resource(directory.directory_id, tags or [])
         return directory.directory_id
 
-    def delete_directory(self, directory_id):
+    def delete_directory(self, directory_id: str) -> str:
         """Delete directory with the matching ID."""
         self._validate_directory_id(directory_id)
         self.directories[directory_id].delete_eni()
@@ -432,14 +445,24 @@ class DirectoryServiceBackend(BaseBackend):
         self.directories.pop(directory_id)
         return directory_id
 
-    def disable_sso(self, directory_id, username=None, password=None):
+    def disable_sso(
+        self,
+        directory_id: str,
+        username: Optional[str] = None,
+        password: Optional[str] = None,
+    ) -> None:
         """Disable single-sign on for a directory."""
         self._validate_directory_id(directory_id)
         validate_args([("ssoPassword", password), ("userName", username)])
         directory = self.directories[directory_id]
         directory.enable_sso(False)
 
-    def enable_sso(self, directory_id, username=None, password=None):
+    def enable_sso(
+        self,
+        directory_id: str,
+        username: Optional[str] = None,
+        password: Optional[str] = None,
+    ) -> None:
         """Enable single-sign on for a directory."""
         self._validate_directory_id(directory_id)
         validate_args([("ssoPassword", password), ("userName", username)])
@@ -454,7 +477,7 @@ class DirectoryServiceBackend(BaseBackend):
         directory.enable_sso(True)
 
     @paginate(pagination_model=PAGINATION_MODEL)
-    def describe_directories(self, directory_ids=None):
+    def describe_directories(self, directory_ids: Optional[List[str]] = None) -> List[Directory]:  # type: ignore[misc]
         """Return info on all directories or directories with matching IDs."""
         for directory_id in directory_ids or self.directories:
             self._validate_directory_id(directory_id)
@@ -464,7 +487,7 @@ class DirectoryServiceBackend(BaseBackend):
             directories = [x for x in directories if x.directory_id in directory_ids]
         return sorted(directories, key=lambda x: x.launch_time)
 
-    def get_directory_limits(self):
+    def get_directory_limits(self) -> Dict[str, Any]:
         """Return hard-coded limits for the directories."""
         counts = {"SimpleAD": 0, "MicrosoftAD": 0, "ConnectedAD": 0}
         for directory in self.directories.values():
@@ -490,7 +513,9 @@ class DirectoryServiceBackend(BaseBackend):
             == Directory.CONNECTED_DIRECTORIES_LIMIT,
         }
 
-    def add_tags_to_resource(self, resource_id, tags):
+    def add_tags_to_resource(
+        self, resource_id: str, tags: List[Dict[str, str]]
+    ) -> None:
         """Add or overwrite one or more tags for specified directory."""
         self._validate_directory_id(resource_id)
         errmsg = self.tagger.validate_tags(tags)
@@ -500,16 +525,16 @@ class DirectoryServiceBackend(BaseBackend):
             raise TagLimitExceededException("Tag limit exceeded")
         self.tagger.tag_resource(resource_id, tags)
 
-    def remove_tags_from_resource(self, resource_id, tag_keys):
+    def remove_tags_from_resource(self, resource_id: str, tag_keys: List[str]) -> None:
         """Removes tags from a directory."""
         self._validate_directory_id(resource_id)
         self.tagger.untag_resource_using_names(resource_id, tag_keys)
 
     @paginate(pagination_model=PAGINATION_MODEL)
-    def list_tags_for_resource(self, resource_id):
+    def list_tags_for_resource(self, resource_id: str) -> List[Dict[str, str]]:  # type: ignore[misc]
         """List all tags on a directory."""
         self._validate_directory_id(resource_id)
-        return self.tagger.list_tags_for_resource(resource_id).get("Tags")
+        return self.tagger.list_tags_for_resource(resource_id).get("Tags")  # type: ignore[return-value]
 
 
 ds_backends = BackendDict(DirectoryServiceBackend, service_name="ds")
