@@ -4,21 +4,21 @@ import json
 from moto.core.exceptions import InvalidToken
 from moto.core.responses import BaseResponse
 from moto.ds.exceptions import InvalidNextTokenException
-from moto.ds.models import ds_backends
+from moto.ds.models import ds_backends, DirectoryServiceBackend
 
 
 class DirectoryServiceResponse(BaseResponse):
     """Handler for DirectoryService requests and responses."""
 
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(service_name="ds")
 
     @property
-    def ds_backend(self):
+    def ds_backend(self) -> DirectoryServiceBackend:
         """Return backend instance specific for this region."""
         return ds_backends[self.current_account][self.region]
 
-    def connect_directory(self):
+    def connect_directory(self) -> str:
         """Create an AD Connector to connect to a self-managed directory."""
         name = self._get_param("Name")
         short_name = self._get_param("ShortName")
@@ -39,7 +39,7 @@ class DirectoryServiceResponse(BaseResponse):
         )
         return json.dumps({"DirectoryId": directory_id})
 
-    def create_directory(self):
+    def create_directory(self) -> str:
         """Create a Simple AD directory."""
         name = self._get_param("Name")
         short_name = self._get_param("ShortName")
@@ -60,14 +60,14 @@ class DirectoryServiceResponse(BaseResponse):
         )
         return json.dumps({"DirectoryId": directory_id})
 
-    def create_alias(self):
+    def create_alias(self) -> str:
         """Create an alias and assign the alias to the directory."""
         directory_id = self._get_param("DirectoryId")
         alias = self._get_param("Alias")
         response = self.ds_backend.create_alias(directory_id, alias)
         return json.dumps(response)
 
-    def create_microsoft_ad(self):
+    def create_microsoft_ad(self) -> str:
         """Create a Microsoft AD directory."""
         name = self._get_param("Name")
         short_name = self._get_param("ShortName")
@@ -88,13 +88,13 @@ class DirectoryServiceResponse(BaseResponse):
         )
         return json.dumps({"DirectoryId": directory_id})
 
-    def delete_directory(self):
+    def delete_directory(self) -> str:
         """Delete a Directory Service directory."""
         directory_id_arg = self._get_param("DirectoryId")
         directory_id = self.ds_backend.delete_directory(directory_id_arg)
         return json.dumps({"DirectoryId": directory_id})
 
-    def describe_directories(self):
+    def describe_directories(self) -> str:
         """Return directory info for the given IDs or all IDs."""
         directory_ids = self._get_param("DirectoryIds")
         next_token = self._get_param("NextToken")
@@ -111,7 +111,7 @@ class DirectoryServiceResponse(BaseResponse):
             response["NextToken"] = next_token
         return json.dumps(response)
 
-    def disable_sso(self):
+    def disable_sso(self) -> str:
         """Disable single-sign on for a directory."""
         directory_id = self._get_param("DirectoryId")
         username = self._get_param("UserName")
@@ -119,7 +119,7 @@ class DirectoryServiceResponse(BaseResponse):
         self.ds_backend.disable_sso(directory_id, username, password)
         return ""
 
-    def enable_sso(self):
+    def enable_sso(self) -> str:
         """Enable single-sign on for a directory."""
         directory_id = self._get_param("DirectoryId")
         username = self._get_param("UserName")
@@ -127,19 +127,19 @@ class DirectoryServiceResponse(BaseResponse):
         self.ds_backend.enable_sso(directory_id, username, password)
         return ""
 
-    def get_directory_limits(self):
+    def get_directory_limits(self) -> str:
         """Return directory limit information for the current region."""
         limits = self.ds_backend.get_directory_limits()
         return json.dumps({"DirectoryLimits": limits})
 
-    def add_tags_to_resource(self):
+    def add_tags_to_resource(self) -> str:
         """Add or overwrite on or more tags for specified directory."""
         resource_id = self._get_param("ResourceId")
         tags = self._get_param("Tags")
         self.ds_backend.add_tags_to_resource(resource_id=resource_id, tags=tags)
         return ""
 
-    def remove_tags_from_resource(self):
+    def remove_tags_from_resource(self) -> str:
         """Removes tags from a directory."""
         resource_id = self._get_param("ResourceId")
         tag_keys = self._get_param("TagKeys")
@@ -148,7 +148,7 @@ class DirectoryServiceResponse(BaseResponse):
         )
         return ""
 
-    def list_tags_for_resource(self):
+    def list_tags_for_resource(self) -> str:
         """Lists all tags on a directory."""
         resource_id = self._get_param("ResourceId")
         next_token = self._get_param("NextToken")
