@@ -3,7 +3,9 @@ import json
 
 import itertools
 from functools import wraps
+from typing import Any, Dict, List, Union, Callable, Optional
 
+from moto.core.common_types import TYPE_RESPONSE
 from moto.core.responses import BaseResponse
 from moto.core.utils import camelcase_to_underscores
 from moto.dynamodb.parsing.key_condition_expression import parse_expression
@@ -13,17 +15,27 @@ from .exceptions import (
     ResourceNotFoundException,
     ConditionalCheckFailed,
 )
-from moto.dynamodb.models import dynamodb_backends, dynamo_json_dump
+from moto.dynamodb.models import dynamodb_backends, Table, DynamoDBBackend
+from moto.dynamodb.models.utilities import dynamo_json_dump
 from moto.utilities.aws_headers import amz_crc32, amzn_request_id
 
 
 TRANSACTION_MAX_ITEMS = 25
 
 
-def include_consumed_capacity(val=1.0):
-    def _inner(f):
+def include_consumed_capacity(
+    val: float = 1.0,
+) -> Callable[
+    [Callable[["DynamoHandler"], str]],
+    Callable[["DynamoHandler"], Union[str, TYPE_RESPONSE]],
+]:
+    def _inner(
+        f: Callable[..., Union[str, TYPE_RESPONSE]]
+    ) -> Callable[["DynamoHandler"], Union[str, TYPE_RESPONSE]]:
         @wraps(f)
-        def _wrapper(*args, **kwargs):
+        def _wrapper(
+            *args: "DynamoHandler", **kwargs: None
+        ) -> Union[str, TYPE_RESPONSE]:
             (handler,) = args
             expected_capacity = handler.body.get("ReturnConsumedCapacity", "NONE")
             if expected_capacity not in ["NONE", "TOTAL", "INDEXES"]:
@@ -67,7 +79,7 @@ def include_consumed_capacity(val=1.0):
     return _inner
 
 
-def get_empty_keys_on_put(field_updates, table):
+def get_empty_keys_on_put(field_updates: Dict[str, Any], table: Table) -> Optional[str]:
     """
     Return the first key-name that has an empty value. None if all keys are filled
     """
@@ -83,12 +95,12 @@ def get_empty_keys_on_put(field_updates, table):
         return next(
             (keyname for keyname in key_names if keyname in empty_str_fields), None
         )
-    return False
+    return None
 
 
-def put_has_empty_attrs(field_updates, table):
+def put_has_empty_attrs(field_updates: Dict[str, Any], table: Table) -> bool:
     # Example invalid attribute: [{'M': {'SS': {'NS': []}}}]
-    def _validate_attr(attr: dict):
+    def _validate_attr(attr: Dict[str, Any]) -> bool:
         if "NS" in attr and attr["NS"] == []:
             return True
         else:
@@ -105,7 +117,17 @@ def put_has_empty_attrs(field_updates, table):
     return False
 
 
-def check_projection_expression(expression):
+def validate_put_has_gsi_keys_set_to_none(item: Dict[str, Any], table: Table) -> None:
+    for gsi in table.global_indexes:
+        for attr in gsi.schema:
+            attr_name = attr["AttributeName"]
+            if attr_name in item and item[attr_name] == {"NULL": True}:
+                raise MockValidationException(
+                    f"One or more parameter values were invalid: Type mismatch for Index Key {attr_name} Expected: S Actual: NULL IndexName: {gsi.name}"
+                )
+
+
+def check_projection_expression(expression: str) -> None:
     if expression.upper() in ReservedKeywords.get_reserved_keywords():
         raise MockValidationException(
             f"ProjectionExpression: Attribute name is a reserved keyword; reserved keyword: {expression}"
@@ -121,10 +143,10 @@ def check_projection_expression(expression):
 
 
 class DynamoHandler(BaseResponse):
-    def __init__(self):
+    def __init__(self) -> None:
         super().__init__(service_name="dynamodb")
 
-    def get_endpoint_name(self, headers):
+    def get_endpoint_name(self, headers: Any) -> Optional[str]:
         """Parses request headers and extracts part od the X-Amz-Target
         that corresponds to a method of DynamoHandler
 
@@ -134,9 +156,10 @@ class DynamoHandler(BaseResponse):
         match = headers.get("x-amz-target") or headers.get("X-Amz-Target")
         if match:
             return match.split(".")[1]
+        return None
 
     @property
-    def dynamodb_backend(self):
+    def dynamodb_backend(self) -> DynamoDBBackend:
         """
         :return: DynamoDB Backend
         :rtype: moto.dynamodb.models.DynamoDBBackend
@@ -145,7 +168,7 @@ class DynamoHandler(BaseResponse):
 
     @amz_crc32
     @amzn_request_id
-    def call_action(self):
+    def call_action(self) -> TYPE_RESPONSE:
         self.body = json.loads(self.body or "{}")
         endpoint = self.get_endpoint_name(self.headers)
         if endpoint:
@@ -161,7 +184,7 @@ class DynamoHandler(BaseResponse):
         else:
             return 404, self.response_headers, ""
 
-    def list_tables(self):
+    def list_tables(self) -> str:
         body = self.body
         limit = body.get("Limit", 100)
         exclusive_start_table_name = body.get("ExclusiveStartTableName")
@@ -169,13 +192,13 @@ class DynamoHandler(BaseResponse):
             limit, exclusive_start_table_name
         )
 
-        response = {"TableNames": tables}
+        response: Dict[str, Any] = {"TableNames": tables}
         if last_eval:
             response["LastEvaluatedTableName"] = last_eval
 
         return dynamo_json_dump(response)
 
-    def create_table(self):
+    def create_table(self) -> str:
         body = self.body
         # get the table name
         table_name = body["TableName"]
@@ -233,7 +256,7 @@ class DynamoHandler(BaseResponse):
         actual_attrs = [item["AttributeName"] for item in attr]
         actual_attrs.sort()
         if actual_attrs != expected_attrs:
-            return self._throw_attr_error(
+            self._throw_attr_error(
                 actual_attrs, expected_attrs, global_indexes or local_secondary_indexes
             )
         # get the stream specification
@@ -255,8 +278,10 @@ class DynamoHandler(BaseResponse):
         )
         return dynamo_json_dump(table.describe())
 
-    def _throw_attr_error(self, actual_attrs, expected_attrs, indexes):
-        def dump_list(list_):
+    def _throw_attr_error(
+        self, actual_attrs: List[str], expected_attrs: List[str], indexes: bool
+    ) -> None:
+        def dump_list(list_: List[str]) -> str:
             return str(list_).replace("'", "")
 
         err_head = "One or more parameter values were invalid: "
@@ -305,28 +330,28 @@ class DynamoHandler(BaseResponse):
                     + dump_list(actual_attrs)
                 )
 
-    def delete_table(self):
+    def delete_table(self) -> str:
         name = self.body["TableName"]
         table = self.dynamodb_backend.delete_table(name)
         return dynamo_json_dump(table.describe())
 
-    def describe_endpoints(self):
+    def describe_endpoints(self) -> str:
         response = {"Endpoints": self.dynamodb_backend.describe_endpoints()}
         return dynamo_json_dump(response)
 
-    def tag_resource(self):
+    def tag_resource(self) -> str:
         table_arn = self.body["ResourceArn"]
         tags = self.body["Tags"]
         self.dynamodb_backend.tag_resource(table_arn, tags)
         return ""
 
-    def untag_resource(self):
+    def untag_resource(self) -> str:
         table_arn = self.body["ResourceArn"]
         tags = self.body["TagKeys"]
         self.dynamodb_backend.untag_resource(table_arn, tags)
         return ""
 
-    def list_tags_of_resource(self):
+    def list_tags_of_resource(self) -> str:
         table_arn = self.body["ResourceArn"]
         all_tags = self.dynamodb_backend.list_tags_of_resource(table_arn)
         all_tag_keys = [tag["Key"] for tag in all_tags]
@@ -344,7 +369,7 @@ class DynamoHandler(BaseResponse):
             return json.dumps({"Tags": tags_resp, "NextToken": next_marker})
         return json.dumps({"Tags": tags_resp})
 
-    def update_table(self):
+    def update_table(self) -> str:
         name = self.body["TableName"]
         attr_definitions = self.body.get("AttributeDefinitions", None)
         global_index = self.body.get("GlobalSecondaryIndexUpdates", None)
@@ -361,13 +386,13 @@ class DynamoHandler(BaseResponse):
         )
         return dynamo_json_dump(table.describe())
 
-    def describe_table(self):
+    def describe_table(self) -> str:
         name = self.body["TableName"]
         table = self.dynamodb_backend.describe_table(name)
         return dynamo_json_dump(table)
 
     @include_consumed_capacity()
-    def put_item(self):
+    def put_item(self) -> str:
         name = self.body["TableName"]
         item = self.body["Item"]
         return_values = self.body.get("ReturnValues", "NONE")
@@ -375,15 +400,17 @@ class DynamoHandler(BaseResponse):
         if return_values not in ("ALL_OLD", "NONE"):
             raise MockValidationException("Return values set to invalid value")
 
-        empty_key = get_empty_keys_on_put(item, self.dynamodb_backend.get_table(name))
+        table = self.dynamodb_backend.get_table(name)
+        empty_key = get_empty_keys_on_put(item, table)
         if empty_key:
             raise MockValidationException(
                 f"One or more parameter values were invalid: An AttributeValue may not contain an empty string. Key: {empty_key}"
             )
-        if put_has_empty_attrs(item, self.dynamodb_backend.get_table(name)):
+        if put_has_empty_attrs(item, table):
             raise MockValidationException(
                 "One or more parameter values were invalid: An number set  may not be empty"
             )
+        validate_put_has_gsi_keys_set_to_none(item, table)
 
         overwrite = "Expected" not in self.body
         if not overwrite:
@@ -424,7 +451,7 @@ class DynamoHandler(BaseResponse):
             item_dict.pop("Attributes", None)
         return dynamo_json_dump(item_dict)
 
-    def batch_write_item(self):
+    def batch_write_item(self) -> str:
         table_batches = self.body["RequestItems"]
         put_requests = []
         delete_requests = []
@@ -466,7 +493,7 @@ class DynamoHandler(BaseResponse):
         return dynamo_json_dump(response)
 
     @include_consumed_capacity(0.5)
-    def get_item(self):
+    def get_item(self) -> str:
         name = self.body["TableName"]
         self.dynamodb_backend.get_table(name)
         key = self.body["Key"]
@@ -508,10 +535,14 @@ class DynamoHandler(BaseResponse):
             # Item not found
             return dynamo_json_dump({})
 
-    def batch_get_item(self):
+    def batch_get_item(self) -> str:
         table_batches = self.body["RequestItems"]
 
-        results = {"ConsumedCapacity": [], "Responses": {}, "UnprocessedKeys": {}}
+        results: Dict[str, Any] = {
+            "ConsumedCapacity": [],
+            "Responses": {},
+            "UnprocessedKeys": {},
+        }
 
         # Validation: Can only request up to 100 items at the same time
         # Scenario 1: We're requesting more than a 100 keys from a single table
@@ -570,7 +601,7 @@ class DynamoHandler(BaseResponse):
             )
         return dynamo_json_dump(results)
 
-    def _contains_duplicates(self, keys):
+    def _contains_duplicates(self, keys: List[str]) -> bool:
         unique_keys = []
         for k in keys:
             if k in unique_keys:
@@ -580,7 +611,7 @@ class DynamoHandler(BaseResponse):
         return False
 
     @include_consumed_capacity()
-    def query(self):
+    def query(self) -> str:
         name = self.body["TableName"]
         key_condition_expression = self.body.get("KeyConditionExpression")
         projection_expression = self.body.get("ProjectionExpression")
@@ -664,7 +695,7 @@ class DynamoHandler(BaseResponse):
             **filter_kwargs,
         )
 
-        result = {
+        result: Dict[str, Any] = {
             "Count": len(items),
             "ScannedCount": scanned_count,
         }
@@ -677,8 +708,10 @@ class DynamoHandler(BaseResponse):
 
         return dynamo_json_dump(result)
 
-    def _adjust_projection_expression(self, projection_expression, expr_attr_names):
-        def _adjust(expression):
+    def _adjust_projection_expression(
+        self, projection_expression: str, expr_attr_names: Dict[str, str]
+    ) -> str:
+        def _adjust(expression: str) -> str:
             return (
                 expr_attr_names[expression]
                 if expression in expr_attr_names
@@ -700,7 +733,7 @@ class DynamoHandler(BaseResponse):
         return projection_expression
 
     @include_consumed_capacity()
-    def scan(self):
+    def scan(self) -> str:
         name = self.body["TableName"]
 
         filters = {}
@@ -748,7 +781,7 @@ class DynamoHandler(BaseResponse):
             result["LastEvaluatedKey"] = last_evaluated_key
         return dynamo_json_dump(result)
 
-    def delete_item(self):
+    def delete_item(self) -> str:
         name = self.body["TableName"]
         key = self.body["Key"]
         return_values = self.body.get("ReturnValues", "NONE")
@@ -783,7 +816,7 @@ class DynamoHandler(BaseResponse):
         item_dict["ConsumedCapacityUnits"] = 0.5
         return dynamo_json_dump(item_dict)
 
-    def update_item(self):
+    def update_item(self) -> str:
         name = self.body["TableName"]
         key = self.body["Key"]
         return_values = self.body.get("ReturnValues", "NONE")
@@ -858,7 +891,7 @@ class DynamoHandler(BaseResponse):
             )
         return dynamo_json_dump(item_dict)
 
-    def _build_updated_new_attributes(self, original, changed):
+    def _build_updated_new_attributes(self, original: Any, changed: Any) -> Any:
         if type(changed) != type(original):
             return changed
         else:
@@ -883,7 +916,7 @@ class DynamoHandler(BaseResponse):
             else:
                 return changed
 
-    def describe_limits(self):
+    def describe_limits(self) -> str:
         return json.dumps(
             {
                 "AccountMaxReadCapacityUnits": 20000,
@@ -893,7 +926,7 @@ class DynamoHandler(BaseResponse):
             }
         )
 
-    def update_time_to_live(self):
+    def update_time_to_live(self) -> str:
         name = self.body["TableName"]
         ttl_spec = self.body["TimeToLiveSpecification"]
 
@@ -901,16 +934,16 @@ class DynamoHandler(BaseResponse):
 
         return json.dumps({"TimeToLiveSpecification": ttl_spec})
 
-    def describe_time_to_live(self):
+    def describe_time_to_live(self) -> str:
         name = self.body["TableName"]
 
         ttl_spec = self.dynamodb_backend.describe_time_to_live(name)
 
         return json.dumps({"TimeToLiveDescription": ttl_spec})
 
-    def transact_get_items(self):
+    def transact_get_items(self) -> str:
         transact_items = self.body["TransactItems"]
-        responses = list()
+        responses: List[Dict[str, Any]] = list()
 
         if len(transact_items) > TRANSACTION_MAX_ITEMS:
             msg = "1 validation error detected: Value '["
@@ -933,7 +966,7 @@ class DynamoHandler(BaseResponse):
             raise MockValidationException(msg)
 
         ret_consumed_capacity = self.body.get("ReturnConsumedCapacity", "NONE")
-        consumed_capacity = dict()
+        consumed_capacity: Dict[str, Any] = dict()
 
         for transact_item in transact_items:
 
@@ -945,7 +978,7 @@ class DynamoHandler(BaseResponse):
                 responses.append({})
                 continue
 
-            item_describe = item.describe_attrs(False)
+            item_describe = item.describe_attrs(attributes=None)
             responses.append(item_describe)
 
             table_capacity = consumed_capacity.get(table_name, {})
@@ -969,20 +1002,20 @@ class DynamoHandler(BaseResponse):
 
         return dynamo_json_dump(result)
 
-    def transact_write_items(self):
+    def transact_write_items(self) -> str:
         transact_items = self.body["TransactItems"]
         self.dynamodb_backend.transact_write_items(transact_items)
-        response = {"ConsumedCapacity": [], "ItemCollectionMetrics": {}}
+        response: Dict[str, Any] = {"ConsumedCapacity": [], "ItemCollectionMetrics": {}}
         return dynamo_json_dump(response)
 
-    def describe_continuous_backups(self):
+    def describe_continuous_backups(self) -> str:
         name = self.body["TableName"]
 
         response = self.dynamodb_backend.describe_continuous_backups(name)
 
         return json.dumps({"ContinuousBackupsDescription": response})
 
-    def update_continuous_backups(self):
+    def update_continuous_backups(self) -> str:
         name = self.body["TableName"]
         point_in_time_spec = self.body["PointInTimeRecoverySpecification"]
 
@@ -992,14 +1025,14 @@ class DynamoHandler(BaseResponse):
 
         return json.dumps({"ContinuousBackupsDescription": response})
 
-    def list_backups(self):
+    def list_backups(self) -> str:
         body = self.body
         table_name = body.get("TableName")
         backups = self.dynamodb_backend.list_backups(table_name)
         response = {"BackupSummaries": [backup.summary for backup in backups]}
         return dynamo_json_dump(response)
 
-    def create_backup(self):
+    def create_backup(self) -> str:
         body = self.body
         table_name = body.get("TableName")
         backup_name = body.get("BackupName")
@@ -1007,21 +1040,21 @@ class DynamoHandler(BaseResponse):
         response = {"BackupDetails": backup.details}
         return dynamo_json_dump(response)
 
-    def delete_backup(self):
+    def delete_backup(self) -> str:
         body = self.body
         backup_arn = body.get("BackupArn")
         backup = self.dynamodb_backend.delete_backup(backup_arn)
         response = {"BackupDescription": backup.description}
         return dynamo_json_dump(response)
 
-    def describe_backup(self):
+    def describe_backup(self) -> str:
         body = self.body
         backup_arn = body.get("BackupArn")
         backup = self.dynamodb_backend.describe_backup(backup_arn)
         response = {"BackupDescription": backup.description}
         return dynamo_json_dump(response)
 
-    def restore_table_from_backup(self):
+    def restore_table_from_backup(self) -> str:
         body = self.body
         target_table_name = body.get("TargetTableName")
         backup_arn = body.get("BackupArn")
@@ -1030,7 +1063,7 @@ class DynamoHandler(BaseResponse):
         )
         return dynamo_json_dump(restored_table.describe())
 
-    def restore_table_to_point_in_time(self):
+    def restore_table_to_point_in_time(self) -> str:
         body = self.body
         target_table_name = body.get("TargetTableName")
         source_table_name = body.get("SourceTableName")
