@@ -1,10 +1,11 @@
+from typing import Dict, List
 from moto.core import BaseModel
 
 from ..exceptions import FilterNotImplementedError
 
 
 class TaggedEC2Resource(BaseModel):
-    def get_tags(self):
+    def get_tags(self) -> List[Dict[str, str]]:
         tags = []
         if self.id:
             tags = self.ec2_backend.describe_tags(filters={"resource-id": [self.id]})
@@ -13,7 +14,7 @@ class TaggedEC2Resource(BaseModel):
     def add_tag(self, key, value):
         self.ec2_backend.create_tags([self.id], {key: value})
 
-    def add_tags(self, tag_map):
+    def add_tags(self, tag_map: Dict[str, str]):
         for key, value in tag_map.items():
             self.ec2_backend.create_tags([self.id], {key: value})
 
