@@ -12,6 +12,7 @@ from ..exceptions import (
     InvalidLaunchTemplateNameAlreadyExistsError,
     InvalidLaunchTemplateNameNotFoundError,
     InvalidLaunchTemplateNameNotFoundWithNameError,
+    MissingParameterError,
 )
 
 
@@ -179,18 +180,24 @@ class LaunchTemplateBackend:
         self.launch_template_insert_order.append(template.id)
         return template
 
-    def get_launch_template(self, template_id):
+    def get_launch_template(self, template_id: str) -> LaunchTemplate:
         return self.launch_templates[template_id]
 
-    def get_launch_template_by_name(self, name):
+    def get_launch_template_by_name(self, name: str) -> LaunchTemplate:
         if name not in self.launch_template_name_to_ids:
             raise InvalidLaunchTemplateNameNotFoundWithNameError(name)
         return self.get_launch_template(self.launch_template_name_to_ids[name])
 
     def delete_launch_template(self, name, tid):
         if name:
-            tid = self.launch_template_name_to_ids[name]
-        return self.launch_templates.pop(tid)
+            tid = self.launch_template_name_to_ids.get(name)
+        if tid is None:
+            raise MissingParameterError("launch template ID or launch template name")
+        if tid not in self.launch_templates:
+            raise InvalidLaunchTemplateNameNotFoundError()
+        template = self.launch_templates.pop(tid)
+        self.launch_template_name_to_ids.pop(template.name, None)
+        return template
 
     def describe_launch_templates(
         self, template_names=None, template_ids=None, filters=None
