@@ -86,6 +86,12 @@ class RouteTable(TaggedEC2Resource, CloudFormationModel):
                 for route in self.routes.values()
                 if route.gateway is not None
             ]
+        elif filter_name == "route.vpc-peering-connection-id":
+            return [
+                route.vpc_pcx.id
+                for route in self.routes.values()
+                if route.vpc_pcx is not None
+            ]
         else:
             return super().get_filter_value(filter_name, "DescribeRouteTables")
 
@@ -156,9 +162,7 @@ class RouteTableBackend:
         route_table = self.get_route_table(route_table_id)
         if route_table.associations:
             raise DependencyViolationError(
-                "The routeTable '{0}' has dependencies and cannot be deleted.".format(
-                    route_table_id
-                )
+                f"The routeTable '{route_table_id}' has dependencies and cannot be deleted."
             )
         self.route_tables.pop(route_table_id)
         return True
