@@ -229,7 +229,7 @@ class InstanceResponse(EC2BaseResponse):
         msg = (
             "This specific call to ModifyInstanceAttribute has not been"
             " implemented in Moto yet. Feel free to open an issue at"
-            " https://github.com/spulec/moto/issues"
+            " https://github.com/getmoto/moto/issues"
         )
         raise NotImplementedError(msg)
 
