@@ -2,8 +2,8 @@
 import re
 from datetime import datetime
 
-from moto.core import BaseBackend, BaseModel
-from moto.core.utils import iso_8601_datetime_without_milliseconds, BackendDict
+from moto.core import BaseBackend, BackendDict, BaseModel
+from moto.core.utils import iso_8601_datetime_without_milliseconds
 
 from .utils import random_cluster_id, random_job_id, get_partition, paginated_list
 from .exceptions import ResourceNotFoundException
