@@ -5,7 +5,7 @@ class IllegalStatusException(JsonRESTError):
     code = 400
 
     def __init__(self, message):
-        super(IllegalStatusException, self).__init__("IllegalStatusException", message)
+        super().__init__("IllegalStatusException", message)
 
 
 class InvalidEventPatternException(JsonRESTError):
@@ -16,31 +16,25 @@ class InvalidEventPatternException(JsonRESTError):
         if reason:
             msg += f"Reason: {reason}"
 
-        super(InvalidEventPatternException, self).__init__(
-            "InvalidEventPatternException", msg
-        )
+        super().__init__("InvalidEventPatternException", msg)
 
 
 class ResourceNotFoundException(JsonRESTError):
     code = 400
 
     def __init__(self, message):
-        super(ResourceNotFoundException, self).__init__(
-            "ResourceNotFoundException", message
-        )
+        super().__init__("ResourceNotFoundException", message)
 
 
 class ResourceAlreadyExistsException(JsonRESTError):
     code = 400
 
     def __init__(self, message):
-        super(ResourceAlreadyExistsException, self).__init__(
-            "ResourceAlreadyExistsException", message
-        )
+        super().__init__("ResourceAlreadyExistsException", message)
 
 
 class ValidationException(JsonRESTError):
     code = 400
 
     def __init__(self, message):
-        super(ValidationException, self).__init__("ValidationException", message)
+        super().__init__("ValidationException", message)
