@@ -1,12 +1,7 @@
 import json
 
 from moto.core.responses import BaseResponse
-from .exceptions import (
-    PartitionAlreadyExistsException,
-    PartitionNotFoundException,
-    TableNotFoundException,
-)
-from .models import glue_backends
+from .models import glue_backends, GlueBackend
 
 
 class GlueResponse(BaseResponse):
@@ -14,8 +9,8 @@ class GlueResponse(BaseResponse):
         super().__init__(service_name="glue")
 
     @property
-    def glue_backend(self):
-        return glue_backends[self.current_account]["global"]
+    def glue_backend(self) -> GlueBackend:
+        return glue_backends[self.current_account][self.region]
 
     @property
     def parameters(self):
@@ -106,7 +101,8 @@ class GlueResponse(BaseResponse):
 
     def get_tables(self):
         database_name = self.parameters.get("DatabaseName")
-        tables = self.glue_backend.get_tables(database_name)
+        expression = self.parameters.get("Expression")
+        tables = self.glue_backend.get_tables(database_name, expression)
         return json.dumps({"TableList": [table.as_dict() for table in tables]})
 
     def delete_table(self):
@@ -118,20 +114,8 @@ class GlueResponse(BaseResponse):
     def batch_delete_table(self):
         database_name = self.parameters.get("DatabaseName")
 
-        errors = []
-        for table_name in self.parameters.get("TablesToDelete"):
-            try:
-                self.glue_backend.delete_table(database_name, table_name)
-            except TableNotFoundException:
-                errors.append(
-                    {
-                        "TableName": table_name,
-                        "ErrorDetail": {
-                            "ErrorCode": "EntityNotFoundException",
-                            "ErrorMessage": "Table not found",
-                        },
-                    }
-                )
+        tables = self.parameters.get("TablesToDelete")
+        errors = self.glue_backend.batch_delete_table(database_name, tables)
 
         out = {}
         if errors:
@@ -165,15 +149,9 @@ class GlueResponse(BaseResponse):
         table_name = self.parameters.get("TableName")
         partitions_to_get = self.parameters.get("PartitionsToGet")
 
-        table = self.glue_backend.get_table(database_name, table_name)
-
-        partitions = []
-        for values in partitions_to_get:
-            try:
-                p = table.get_partition(values=values["Values"])
-                partitions.append(p.as_dict())
-            except PartitionNotFoundException:
-                continue
+        partitions = self.glue_backend.batch_get_partition(
+            database_name, table_name, partitions_to_get
+        )
 
         return json.dumps({"Partitions": partitions})
 
@@ -190,22 +168,10 @@ class GlueResponse(BaseResponse):
     def batch_create_partition(self):
         database_name = self.parameters.get("DatabaseName")
         table_name = self.parameters.get("TableName")
-        table = self.glue_backend.get_table(database_name, table_name)
-
-        errors_output = []
-        for part_input in self.parameters.get("PartitionInputList"):
-            try:
-                table.create_partition(part_input)
-            except PartitionAlreadyExistsException:
-                errors_output.append(
-                    {
-                        "PartitionValues": part_input["Values"],
-                        "ErrorDetail": {
-                            "ErrorCode": "AlreadyExistsException",
-                            "ErrorMessage": "Partition already exists.",
-                        },
-                    }
-                )
+        partition_input = self.parameters.get("PartitionInputList")
+        errors_output = self.glue_backend.batch_create_partition(
+            database_name, table_name, partition_input
+        )
 
         out = {}
         if errors_output:
@@ -227,25 +193,11 @@ class GlueResponse(BaseResponse):
     def batch_update_partition(self):
         database_name = self.parameters.get("DatabaseName")
         table_name = self.parameters.get("TableName")
-        table = self.glue_backend.get_table(database_name, table_name)
+        entries = self.parameters.get("Entries")
 
-        errors_output = []
-        for entry in self.parameters.get("Entries"):
-            part_to_update = entry["PartitionValueList"]
-            part_input = entry["PartitionInput"]
-
-            try:
-                table.update_partition(part_to_update, part_input)
-            except PartitionNotFoundException:
-                errors_output.append(
-                    {
-                        "PartitionValueList": part_to_update,
-                        "ErrorDetail": {
-                            "ErrorCode": "EntityNotFoundException",
-                            "ErrorMessage": "Partition not found.",
-                        },
-                    }
-                )
+        errors_output = self.glue_backend.batch_update_partition(
+            database_name, table_name, entries
+        )
 
         out = {}
         if errors_output:
@@ -266,23 +218,11 @@ class GlueResponse(BaseResponse):
     def batch_delete_partition(self):
         database_name = self.parameters.get("DatabaseName")
         table_name = self.parameters.get("TableName")
-        table = self.glue_backend.get_table(database_name, table_name)
+        parts = self.parameters.get("PartitionsToDelete")
 
-        errors_output = []
-        for part_input in self.parameters.get("PartitionsToDelete"):
-            values = part_input.get("Values")
-            try:
-                table.delete_partition(values)
-            except PartitionNotFoundException:
-                errors_output.append(
-                    {
-                        "PartitionValues": values,
-                        "ErrorDetail": {
-                            "ErrorCode": "EntityNotFoundException",
-                            "ErrorMessage": "Partition not found",
-                        },
-                    }
-                )
+        errors_output = self.glue_backend.batch_delete_partition(
+            database_name, table_name, parts
+        )
 
         out = {}
         if errors_output:
@@ -473,6 +413,20 @@ class GlueResponse(BaseResponse):
         registry = self.glue_backend.create_registry(registry_name, description, tags)
         return json.dumps(registry)
 
+    def delete_registry(self):
+        registry_id = self._get_param("RegistryId")
+        registry = self.glue_backend.delete_registry(registry_id)
+        return json.dumps(registry)
+
+    def get_registry(self):
+        registry_id = self._get_param("RegistryId")
+        registry = self.glue_backend.get_registry(registry_id)
+        return json.dumps(registry)
+
+    def list_registries(self):
+        registries = self.glue_backend.list_registries()
+        return json.dumps({"Registries": registries})
+
     def create_schema(self):
         registry_id = self._get_param("RegistryId")
         schema_name = self._get_param("SchemaName")
@@ -528,7 +482,19 @@ class GlueResponse(BaseResponse):
         )
         return json.dumps(schema_version)
 
+    def get_schema(self):
+        schema_id = self._get_param("SchemaId")
+        schema = self.glue_backend.get_schema(schema_id)
+        return json.dumps(schema)
+
     def delete_schema(self):
         schema_id = self._get_param("SchemaId")
         schema = self.glue_backend.delete_schema(schema_id)
         return json.dumps(schema)
+
+    def update_schema(self):
+        schema_id = self._get_param("SchemaId")
+        compatibility = self._get_param("Compatibility")
+        description = self._get_param("Description")
+        schema = self.glue_backend.update_schema(schema_id, compatibility, description)
+        return json.dumps(schema)
