@@ -5,8 +5,8 @@ import itertools
 
 from operator import attrgetter
 
-from moto.core import BaseBackend, BaseModel, CloudFormationModel
-from moto.core.utils import unix_time, BackendDict
+from moto.core import BaseBackend, BackendDict, BaseModel, CloudFormationModel
+from moto.core.utils import unix_time
 from moto.utilities.paginator import paginate
 from moto.utilities.utils import md5_hash
 from .exceptions import (
@@ -85,7 +85,7 @@ class Shard(BaseModel):
 
     @property
     def shard_id(self):
-        return "shardId-{0}".format(str(self._shard_id).zfill(12))
+        return f"shardId-{str(self._shard_id).zfill(12)}"
 
     def get_records(self, last_sequence_id, limit):
         last_sequence_id = int(last_sequence_id)
