@@ -5,28 +5,28 @@ class NotFoundException(JsonRESTError):
     code = 400
 
     def __init__(self, message):
-        super(NotFoundException, self).__init__("NotFoundException", message)
+        super().__init__("NotFoundException", message)
 
 
 class ValidationException(JsonRESTError):
     code = 400
 
     def __init__(self, message):
-        super(ValidationException, self).__init__("ValidationException", message)
+        super().__init__("ValidationException", message)
 
 
 class AlreadyExistsException(JsonRESTError):
     code = 400
 
     def __init__(self, message):
-        super(AlreadyExistsException, self).__init__("AlreadyExistsException", message)
+        super().__init__("AlreadyExistsException", message)
 
 
 class NotAuthorizedException(JsonRESTError):
     code = 400
 
     def __init__(self):
-        super(NotAuthorizedException, self).__init__("NotAuthorizedException", None)
+        super().__init__("NotAuthorizedException", None)
 
         self.description = '{"__type":"NotAuthorizedException"}'
 
@@ -35,7 +35,7 @@ class AccessDeniedException(JsonRESTError):
     code = 400
 
     def __init__(self, message):
-        super(AccessDeniedException, self).__init__("AccessDeniedException", message)
+        super().__init__("AccessDeniedException", message)
 
         self.description = '{"__type":"AccessDeniedException"}'
 
@@ -44,8 +44,6 @@ class InvalidCiphertextException(JsonRESTError):
     code = 400
 
     def __init__(self):
-        super(InvalidCiphertextException, self).__init__(
-            "InvalidCiphertextException", None
-        )
+        super().__init__("InvalidCiphertextException", None)
 
         self.description = '{"__type":"InvalidCiphertextException"}'
