@@ -1,7 +1,6 @@
 from collections import OrderedDict
 
-from moto.core import BaseBackend, BaseModel
-from moto.core.utils import BackendDict
+from moto.core import BaseBackend, BackendDict, BaseModel
 
 from .exceptions import ClientError
 
@@ -68,19 +67,13 @@ class OriginEndpoint(BaseModel):
 
 
 class MediaPackageBackend(BaseBackend):
-    def __init__(self, region_name=None):
-        super().__init__()
-        self.region_name = region_name
+    def __init__(self, region_name, account_id):
+        super().__init__(region_name, account_id)
         self._channels = OrderedDict()
         self._origin_endpoints = OrderedDict()
 
-    def reset(self):
-        region_name = self.region_name
-        self.__dict__ = {}
-        self.__init__(region_name)
-
     def create_channel(self, description, channel_id, tags):
-        arn = "arn:aws:mediapackage:channel:{}".format(channel_id)
+        arn = f"arn:aws:mediapackage:channel:{channel_id}"
         channel = Channel(
             arn=arn,
             description=description,
@@ -104,7 +97,7 @@ class MediaPackageBackend(BaseBackend):
             return channel.to_dict()
         except KeyError:
             error = "NotFoundException"
-            raise ClientError(error, "channel with id={} not found".format(channel_id))
+            raise ClientError(error, f"channel with id={channel_id} not found")
 
     def delete_channel(self, channel_id):
         try:
@@ -114,7 +107,7 @@ class MediaPackageBackend(BaseBackend):
 
         except KeyError:
             error = "NotFoundException"
-            raise ClientError(error, "channel with id={} not found".format(channel_id))
+            raise ClientError(error, f"channel with id={channel_id} not found")
 
     def create_origin_endpoint(
         self,
@@ -133,10 +126,8 @@ class MediaPackageBackend(BaseBackend):
         time_delay_seconds,
         whitelist,
     ):
-        arn = "arn:aws:mediapackage:origin_endpoint:{}".format(endpoint_id)
-        url = "https://origin-endpoint.mediapackage.{}.amazonaws.com/{}".format(
-            self.region_name, endpoint_id
-        )
+        arn = f"arn:aws:mediapackage:origin_endpoint:{endpoint_id}"
+        url = f"https://origin-endpoint.mediapackage.{self.region_name}.amazonaws.com/{endpoint_id}"
         origin_endpoint = OriginEndpoint(
             arn=arn,
             authorization=authorization,
@@ -164,9 +155,7 @@ class MediaPackageBackend(BaseBackend):
             return origin_endpoint.to_dict()
         except KeyError:
             error = "NotFoundException"
-            raise ClientError(
-                error, "origin endpoint with id={} not found".format(endpoint_id)
-            )
+            raise ClientError(error, f"origin endpoint with id={endpoint_id} not found")
 
     def list_origin_endpoints(self):
         origin_endpoints = list(self._origin_endpoints.values())
@@ -180,9 +169,7 @@ class MediaPackageBackend(BaseBackend):
             return origin_endpoint.to_dict()
         except KeyError:
             error = "NotFoundException"
-            raise ClientError(
-                error, "origin endpoint with id={} not found".format(endpoint_id)
-            )
+            raise ClientError(error, f"origin endpoint with id={endpoint_id} not found")
 
     def update_origin_endpoint(
         self,
@@ -216,9 +203,7 @@ class MediaPackageBackend(BaseBackend):
 
         except KeyError:
             error = "NotFoundException"
-        raise ClientError(
-            error, "origin endpoint with id={} not found".format(endpoint_id)
-        )
+        raise ClientError(error, f"origin endpoint with id={endpoint_id} not found")
 
 
 mediapackage_backends = BackendDict(MediaPackageBackend, "mediapackage")
