@@ -1,8 +1,7 @@
 import hashlib
 from collections import OrderedDict
 
-from moto.core import BaseBackend, BaseModel
-from moto.core.utils import BackendDict
+from moto.core import BaseBackend, BackendDict, BaseModel
 from .exceptions import ClientError
 
 
@@ -46,7 +45,7 @@ class MediaStoreDataBackend(BaseBackend):
     def delete_object(self, path):
         if path not in self._objects:
             error = "ObjectNotFoundException"
-            raise ClientError(error, "Object with id={} not found".format(path))
+            raise ClientError(error, f"Object with id={path} not found")
         del self._objects[path]
         return {}
 
@@ -57,7 +56,7 @@ class MediaStoreDataBackend(BaseBackend):
         objects_found = [item for item in self._objects.values() if item.path == path]
         if len(objects_found) == 0:
             error = "ObjectNotFoundException"
-            raise ClientError(error, "Object with id={} not found".format(path))
+            raise ClientError(error, f"Object with id={path} not found")
         return objects_found[0]
 
     def list_items(self):
