@@ -465,6 +465,52 @@ class SageMakerResponse(BaseResponse):
         response = self.sagemaker_backend.list_associations(self.request_params)
         return 200, {}, json.dumps(response)
 
+    @amzn_request_id
+    def describe_pipeline(self):
+        response = self.sagemaker_backend.describe_pipeline(
+            self._get_param("PipelineName")
+        )
+        return 200, {}, json.dumps(response)
+
+    @amzn_request_id
+    def start_pipeline_execution(self):
+        response = self.sagemaker_backend.start_pipeline_execution(
+            self._get_param("PipelineName"),
+            self._get_param("PipelineExecutionDisplayName"),
+            self._get_param("PipelineParameters"),
+            self._get_param("PipelineExecutionDescription"),
+            self._get_param("ParallelismConfiguration"),
+        )
+        return 200, {}, json.dumps(response)
+
+    @amzn_request_id
+    def describe_pipeline_execution(self):
+        response = self.sagemaker_backend.describe_pipeline_execution(
+            self._get_param("PipelineExecutionArn")
+        )
+        return 200, {}, json.dumps(response)
+
+    @amzn_request_id
+    def describe_pipeline_definition_for_execution(self):
+        response = self.sagemaker_backend.describe_pipeline_definition_for_execution(
+            self._get_param("PipelineExecutionArn")
+        )
+        return 200, {}, json.dumps(response)
+
+    @amzn_request_id
+    def list_pipeline_parameters_for_execution(self):
+        response = self.sagemaker_backend.list_pipeline_parameters_for_execution(
+            self._get_param("PipelineExecutionArn")
+        )
+        return 200, {}, json.dumps(response)
+
+    @amzn_request_id
+    def list_pipeline_executions(self):
+        response = self.sagemaker_backend.list_pipeline_executions(
+            self._get_param("PipelineName")
+        )
+        return 200, {}, json.dumps(response)
+
     @amzn_request_id
     def create_pipeline(self):
         pipeline = self.sagemaker_backend.create_pipeline(
@@ -493,6 +539,23 @@ class SageMakerResponse(BaseResponse):
         response = {"PipelineArn": pipeline_arn}
         return 200, {}, json.dumps(response)
 
+    @amzn_request_id
+    def update_pipeline(self):
+        pipeline_arn = self.sagemaker_backend.update_pipeline(
+            pipeline_name=self._get_param("PipelineName"),
+            pipeline_display_name=self._get_param("PipelineDisplayName"),
+            pipeline_definition=self._get_param("PipelineDefinition"),
+            pipeline_definition_s3_location=self._get_param(
+                "PipelineDefinitionS3Location"
+            ),
+            pipeline_description=self._get_param("PipelineDescription"),
+            role_arn=self._get_param("RoleArn"),
+            parallelism_configuration=self._get_param("ParallelismConfiguration"),
+        )
+
+        response = {"PipelineArn": pipeline_arn}
+        return 200, {}, json.dumps(response)
+
     @amzn_request_id
     def list_pipelines(self):
         max_results_range = range(1, 101)
