@@ -15,6 +15,13 @@ class ConfigurationSetDoesNotExist(RESTError):
         super().__init__("ConfigurationSetDoesNotExist", message)
 
 
+class ConfigurationSetAlreadyExists(RESTError):
+    code = 400
+
+    def __init__(self, message):
+        super().__init__("ConfigurationSetAlreadyExists", message)
+
+
 class EventDestinationAlreadyExists(RESTError):
     code = 400
 
@@ -91,5 +98,5 @@ class MissingRenderingAttributeException(RESTError):
     def __init__(self, var):
         super().__init__(
             "MissingRenderingAttributeException",
-            "Attribute '{0}' is not present in the rendering data.".format(var),
+            f"Attribute '{var}' is not present in the rendering data.",
         )
