@@ -36,7 +36,7 @@ class InvalidToken(AWSError):
     STATUS = 400
 
     def __init__(self, message="Invalid token"):
-        super(InvalidToken, self).__init__("Invalid Token: {}".format(message))
+        super().__init__(f"Invalid Token: {message}")
 
 
 class ResourceNotFound(AWSError):
@@ -44,4 +44,4 @@ class ResourceNotFound(AWSError):
     STATUS = 400
 
     def __init__(self, arn):
-        super(ResourceNotFound, self).__init__("Resource not found: '{}'".format(arn))
+        super().__init__(f"Resource not found: '{arn}'")
