@@ -1,6 +1,4 @@
 from moto.core.responses import BaseResponse
-from moto.core import get_account_id
-from moto.iam import iam_backends
 from .exceptions import STSValidationError
 from .models import sts_backends
 
@@ -8,9 +6,12 @@ MAX_FEDERATION_TOKEN_POLICY_LENGTH = 2048
 
 
 class TokenResponse(BaseResponse):
+    def __init__(self):
+        super().__init__(service_name="sts")
+
     @property
     def backend(self):
-        return sts_backends["global"]
+        return sts_backends[self.current_account]["global"]
 
     def get_session_token(self):
         duration = int(self.querystring.get("DurationSeconds", [43200])[0])
@@ -27,13 +28,13 @@ class TokenResponse(BaseResponse):
                 "1 validation error detected: Value "
                 '\'{"Version": "2012-10-17", "Statement": [...]}\' '
                 "at 'policy' failed to satisfy constraint: Member must have length less than or "
-                " equal to %s" % MAX_FEDERATION_TOKEN_POLICY_LENGTH
+                f" equal to {MAX_FEDERATION_TOKEN_POLICY_LENGTH}"
             )
 
         name = self.querystring.get("Name")[0]
         token = self.backend.get_federation_token(duration=duration, name=name)
         template = self.response_template(GET_FEDERATION_TOKEN_RESPONSE)
-        return template.render(token=token, account_id=get_account_id())
+        return template.render(token=token, account_id=self.current_account)
 
     def assume_role(self):
         role_session_name = self.querystring.get("RoleSessionName")[0]
@@ -87,22 +88,10 @@ class TokenResponse(BaseResponse):
     def get_caller_identity(self):
         template = self.response_template(GET_CALLER_IDENTITY_RESPONSE)
 
-        # Default values in case the request does not use valid credentials generated by moto
-        user_id = "AKIAIOSFODNN7EXAMPLE"
-        arn = "arn:aws:sts::{account_id}:user/moto".format(account_id=get_account_id())
+        access_key_id = self.get_access_key()
+        user_id, arn, account_id = self.backend.get_caller_identity(access_key_id)
 
-        access_key_id = self.get_current_user()
-        assumed_role = self.backend.get_assumed_role_from_access_key(access_key_id)
-        if assumed_role:
-            user_id = assumed_role.user_id
-            arn = assumed_role.arn
-
-        user = iam_backends["global"].get_user_from_access_key_id(access_key_id)
-        if user:
-            user_id = user.id
-            arn = user.arn
-
-        return template.render(account_id=get_account_id(), user_id=user_id, arn=arn)
+        return template.render(account_id=account_id, user_id=user_id, arn=arn)
 
 
 GET_SESSION_TOKEN_RESPONSE = """<GetSessionTokenResponse xmlns="https://sts.amazonaws.com/doc/2011-06-15/">
